==> haskell-errors-2.2.1-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: errors
version: 2.2.1
id: errors-2.2.1-1n5FgR4mpQ2Jw0nLNvC0nv
key: errors-2.2.1-1n5FgR4mpQ2Jw0nLNvC0nv
license: BSD3
copyright: 2012, 2013 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
synopsis: Simplified error-handling
description:
    The one-stop shop for all your error-handling needs!  Just import
    "Control.Error".
    .
    This library encourages an error-handling style that directly uses the type
    system, rather than out-of-band exceptions.
category: Control, Error Handling
author: Gabriel Gonzalez
exposed: True
indefinite: False
exposed-modules:
    Control.Error Control.Error.Safe Control.Error.Script
    Control.Error.Util Data.EitherR
abi: 381dd930a9d578a83fe382d54b67344e
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/errors-2.2.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/errors-2.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/errors-2.2.1
hs-libraries: HSerrors-2.2.1-1n5FgR4mpQ2Jw0nLNvC0nv
depends:
    base-4.10.0.0 exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz transformers-0.5.2.0
    transformers-compat-0.5.1.4-8ofY1OHzPhX5dvYk512o2v
    unexceptionalio-0.3.0-2Qrq3kcp0PEBvJTmGgkrK4
    safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6=e190029673d5410544b32623a0e81f5f
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             transformers-compat-0.5.1.4-8ofY1OHzPhX5dvYk512o2v=cbaa4957cb14b8a9e85ebeab0ab7d6ba
             unexceptionalio-0.3.0-2Qrq3kcp0PEBvJTmGgkrK4=3d2f66864f260fa643bed05649f7fe57
             safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5=6cf1fe7158a61976010b5254caed2ddd
haddock-interfaces: /usr/share/doc/haskell-errors/html/errors.haddock
haddock-html: /usr/share/doc/haskell-errors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-errors-2.2.2-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: errors
version: 2.2.2
id: errors-2.2.2-55dL44uoGvGA1pVVvEb4s7
key: errors-2.2.2-55dL44uoGvGA1pVVvEb4s7
license: BSD3
copyright: 2012, 2013 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
synopsis: Simplified error-handling
description:
    The one-stop shop for all your error-handling needs!  Just import
    "Control.Error".
    .
    This library encourages an error-handling style that directly uses the type
    system, rather than out-of-band exceptions.
category: Control, Error Handling
author: Gabriel Gonzalez
exposed: True
indefinite: False
exposed-modules:
    Control.Error Control.Error.Safe Control.Error.Script
    Control.Error.Util Data.EitherR
abi: 6f91e0aa3a7d85f06b19237b3848b658
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/errors-2.2.2
library-dirs: /usr/lib/ghc-8.2.1/site-local/errors-2.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/errors-2.2.2
hs-libraries: HSerrors-2.2.2-55dL44uoGvGA1pVVvEb4s7
depends:
    base-4.10.0.0 exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz transformers-0.5.2.0
    transformers-compat-0.5.1.4-8ofY1OHzPhX5dvYk512o2v
    unexceptionalio-0.3.0-2Qrq3kcp0PEBvJTmGgkrK4
    safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6=e190029673d5410544b32623a0e81f5f
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             transformers-compat-0.5.1.4-8ofY1OHzPhX5dvYk512o2v=cbaa4957cb14b8a9e85ebeab0ab7d6ba
             unexceptionalio-0.3.0-2Qrq3kcp0PEBvJTmGgkrK4=3d2f66864f260fa643bed05649f7fe57
             safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5=6cf1fe7158a61976010b5254caed2ddd
haddock-interfaces: /usr/share/doc/haskell-errors/html/errors.haddock
haddock-html: /usr/share/doc/haskell-errors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
